summaryrefslogtreecommitdiffstats
path: root/kbarcode/batchprinter.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commite295fa9ed9bf0a1ce153cd3e92a6fc24b9316933 (patch)
tree5c70aff00550c3512d6ec34ef333e0944a08db20 /kbarcode/batchprinter.h
parent33038ab0e8b8e7fb05093f953e4f6f724c6e2482 (diff)
downloadkbarcode-e295fa9ed9bf0a1ce153cd3e92a6fc24b9316933.tar.gz
kbarcode-e295fa9ed9bf0a1ce153cd3e92a6fc24b9316933.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kbarcode@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kbarcode/batchprinter.h')
-rw-r--r--kbarcode/batchprinter.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kbarcode/batchprinter.h b/kbarcode/batchprinter.h
index ed06a9e..782b89e 100644
--- a/kbarcode/batchprinter.h
+++ b/kbarcode/batchprinter.h
@@ -204,9 +204,9 @@ class BatchPrinter
TQBuffer* buffer;
KPrinter* printer;
TQPainter* painter;
/** tqparent for dialogs
*/
- TQWidget* tqparent;
+ TQWidget* parent;
};
#endif
@@ -204,9 +204,9 @@ class BatchPrinter
KPrinter* printer;
TQPainter* painter;
- /** tqparent for dialogs
+ /** parent for dialogs
*/